package Test::Circle2;
# ABSTRACT: ...

use strict;
use warnings;

our $VERSION = '0.009';

=head1 NAME

Test::Circle2 - Module abstract

=head1 SYNOPSIS

    use Test::Circle2;
    my $instance = Test::Circle2->new;

=head1 DESCRIPTION

=cut

=head1 METHODS

=cut

1;

=head1 SEE ALSO

=over 4

=item *

=back

